==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1CSIPersistentVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

public interface V1CSIPersistentVolumeSourceFluent<A extends V1CSIPersistentVolumeSourceFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildControllerPublishSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1SecretReference getControllerPublishSecretRef();
    public V1SecretReference buildControllerPublishSecretRef();
    public A withControllerPublishSecretRef(V1SecretReference controllerPublishSecretRef);
    public Boolean hasControllerPublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> withNewControllerPublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> withNewControllerPublishSecretRefLike(V1SecretReference item);
    public V1CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editControllerPublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editOrNewControllerPublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editOrNewControllerPublishSecretRefLike(V1SecretReference item);
    public String getDriver();
    public A withDriver(String driver);
    public Boolean hasDriver();
    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    
/**
 * This method has been deprecated, please use method buildNodePublishSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1SecretReference getNodePublishSecretRef();
    public V1SecretReference buildNodePublishSecretRef();
    public A withNodePublishSecretRef(V1SecretReference nodePublishSecretRef);
    public Boolean hasNodePublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRefLike(V1SecretReference item);
    public V1CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editNodePublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRefLike(V1SecretReference item);
    
/**
 * This method has been deprecated, please use method buildNodeStageSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1SecretReference getNodeStageSecretRef();
    public V1SecretReference buildNodeStageSecretRef();
    public A withNodeStageSecretRef(V1SecretReference nodeStageSecretRef);
    public Boolean hasNodeStageSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> withNewNodeStageSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> withNewNodeStageSecretRefLike(V1SecretReference item);
    public V1CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editNodeStageSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editOrNewNodeStageSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editOrNewNodeStageSecretRefLike(V1SecretReference item);
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(boolean arg1);
    public A withNewReadOnly(String arg1);
    public A addToVolumeAttributes(String key,String value);
    public A addToVolumeAttributes(Map<String,String> map);
    public A removeFromVolumeAttributes(String key);
    public A removeFromVolumeAttributes(Map<String,String> map);
    public Map<String,String> getVolumeAttributes();
    public A withVolumeAttributes(Map<String,String> volumeAttributes);
    public Boolean hasVolumeAttributes();
    public String getVolumeHandle();
    public A withVolumeHandle(String volumeHandle);
    public Boolean hasVolumeHandle();

    public interface ControllerPublishSecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1SecretReferenceFluent<V1CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<N>>{

        
    public N and();    public N endControllerPublishSecretRef();
}
    public interface NodePublishSecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1SecretReferenceFluent<V1CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<N>>{

        
    public N and();    public N endNodePublishSecretRef();
}
    public interface NodeStageSecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1SecretReferenceFluent<V1CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<N>>{

        
    public N and();    public N endNodeStageSecretRef();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1CSIPersistentVolumeSourceFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

public interface V1CSIPersistentVolumeSourceFluent<A extends V1CSIPersistentVolumeSourceFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildControllerPublishSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1SecretReference getControllerPublishSecretRef();
    public V1SecretReference buildControllerPublishSecretRef();
    public A withControllerPublishSecretRef(V1SecretReference controllerPublishSecretRef);
    public Boolean hasControllerPublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> withNewControllerPublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> withNewControllerPublishSecretRefLike(V1SecretReference item);
    public V1CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editControllerPublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editOrNewControllerPublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<A> editOrNewControllerPublishSecretRefLike(V1SecretReference item);
    public String getDriver();
    public A withDriver(String driver);
    public Boolean hasDriver();
    public A withNewDriver(String arg1);
    public A withNewDriver(StringBuilder arg1);
    public A withNewDriver(StringBuffer arg1);
    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(String arg1);
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildNodePublishSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1SecretReference getNodePublishSecretRef();
    public V1SecretReference buildNodePublishSecretRef();
    public A withNodePublishSecretRef(V1SecretReference nodePublishSecretRef);
    public Boolean hasNodePublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> withNewNodePublishSecretRefLike(V1SecretReference item);
    public V1CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editNodePublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<A> editOrNewNodePublishSecretRefLike(V1SecretReference item);
    
/**
 * This method has been deprecated, please use method buildNodeStageSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public V1SecretReference getNodeStageSecretRef();
    public V1SecretReference buildNodeStageSecretRef();
    public A withNodeStageSecretRef(V1SecretReference nodeStageSecretRef);
    public Boolean hasNodeStageSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> withNewNodeStageSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> withNewNodeStageSecretRefLike(V1SecretReference item);
    public V1CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editNodeStageSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editOrNewNodeStageSecretRef();
    public V1CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<A> editOrNewNodeStageSecretRefLike(V1SecretReference item);
    public Boolean isReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    public A addToVolumeAttributes(String key,String value);
    public A addToVolumeAttributes(Map<String,String> map);
    public A removeFromVolumeAttributes(String key);
    public A removeFromVolumeAttributes(Map<String,String> map);
    public Map<String,String> getVolumeAttributes();
    public A withVolumeAttributes(Map<String,String> volumeAttributes);
    public Boolean hasVolumeAttributes();
    public String getVolumeHandle();
    public A withVolumeHandle(String volumeHandle);
    public Boolean hasVolumeHandle();
    public A withNewVolumeHandle(String arg1);
    public A withNewVolumeHandle(StringBuilder arg1);
    public A withNewVolumeHandle(StringBuffer arg1);

    public interface ControllerPublishSecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1SecretReferenceFluent<V1CSIPersistentVolumeSourceFluent.ControllerPublishSecretRefNested<N>>{

        
    public N and();    public N endControllerPublishSecretRef();
}
    public interface NodePublishSecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1SecretReferenceFluent<V1CSIPersistentVolumeSourceFluent.NodePublishSecretRefNested<N>>{

        
    public N and();    public N endNodePublishSecretRef();
}
    public interface NodeStageSecretRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1SecretReferenceFluent<V1CSIPersistentVolumeSourceFluent.NodeStageSecretRefNested<N>>{

        
    public N and();    public N endNodeStageSecretRef();
}


}
